@@ -1,5 +1,5 @@
 package Pod::Autopod; ## Generates pod documentation by analysing perl modules.
-$Pod::Autopod::VERSION = '1.209';
+$Pod::Autopod::VERSION = '1.210';
 use 5.006; #Pod::Abstract uses features of 5.6
 use FileHandle;
 use strict;
@@ -476,7 +476,7 @@ my @fm;
 
 	@f=$self->_getDirArray($path);
 
-	$self->_filterFileArray(\@f);
+	#$self->_filterFileArray(\@f);
 	$self->_addPathToArray($path,\@f);
 
 	foreach my $d (@f){
